package pkiws

import (
	"fmt"
	"log"
	"net/http"

	"git.paulbsd.com/paulbsd/pki/src/config"
	"git.paulbsd.com/paulbsd/pki/src/pki"

	"github.com/labstack/echo/v4"
	"github.com/labstack/echo/v4/middleware"
)

// RunServer runs the main echo HTTP server
func RunServer(cfg *config.Config) (err error) {
	e := echo.New()

	e.Use(middleware.BasicAuth(func(username, password string, c echo.Context) (bool, error) {
		res, user, err := Auth(cfg, username, password, c)
		if res {
			c.Set("username", username)
			c.Set("user", user)
		}
		return res, err
	}))
	e.HideBanner = cfg.Options.HideBanner

	e.GET("/", func(c echo.Context) error {
		username := c.Get("username")
		return c.String(http.StatusOK, fmt.Sprintf("username: %s", username))
	})
	e.GET("/domain/:domain", func(c echo.Context) (err error) {
		var result EntryResponse
		log.Println(fmt.Sprintf("Providing %s to user %s at %s", c.Param("domain"), c.Get("username"), c.RealIP()))
		result, err = GetCertificate(cfg, c.Get("user").(*pki.User), c.Param("domain"))
		if err != nil {
			return c.String(http.StatusInternalServerError, fmt.Sprintf("%s %s", result, err))
		}
		return c.JSON(http.StatusOK, result)
	})
	e.GET("/config", func(c echo.Context) (err error) {
		if ConfigAccess(*cfg, c.RealIP()) {
			return c.JSON(http.StatusOK, cfg)
		}
		return c.String(http.StatusForbidden, "Forbidden")
	})

	e.Logger.Fatal(e.Start(fmt.Sprintf(":%d", cfg.Switchs.Port)))
	return
}
